/* Major version number */
#define LASSO_VERSION_MAJOR @VERSION_MAJOR@

/* Minor version number */
#define LASSO_VERSION_MINOR @VERSION_MINOR@

/* Release version number */
#define LASSO_VERSION_SUBMINOR @VERSION_RELEASE@

/* Windows version of the lasso version */
#define LASSO_WINDOWS_VERSION 2,3,5,0

/* Define if ID-WSF support is enabled */
/* #undef LASSO_WSF_ENABLED */
#if 0
#  define LASSO_WSF_ENABLED
#else
#  undef LASSO_WSF_ENABLED
#endif

/* Name of package */
#define PACKAGE "lasso"

/* Define to the address where bug reports for this package should be sent. */
#define PACKAGE_BUGREPORT "lasso-devel@lists.labs.libre-entreprise.org"

/* Define to the full name of this package. */
#define PACKAGE_NAME "lasso"

/* Define to the full name and version of this package. */
#define PACKAGE_STRING "lasso 2.3.5"

/* Define to the one symbol short name of this package. */
#define PACKAGE_TARNAME "lasso"

/* Define to the version of this package. */
#define PACKAGE_VERSION "2.3.5"

/* Version number of package */
#define VERSION "2.3.5"

